# Generated by Django 2.2.24 on 2021-11-15 13:49

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_editor', '0008_auto_20201008_1430'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='codefragment',
            options={'default_permissions': ['add', 'change', 'delete', 'view', 'control']},
        ),
        migrations.AlterModelOptions(
            name='helloworld',
            options={'default_permissions': ['add', 'change', 'delete', 'view', 'control']},
        ),
        migrations.AddField(
            model_name='codefragment',
            name='description_en',
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='codefragment',
            name='description_fr',
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='codefragment',
            name='title_en',
            field=models.CharField(max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='codefragment',
            name='title_fr',
            field=models.CharField(max_length=255, null=True),
        ),
    ]
