# Generated by Django 2.2.16 on 2020-10-08 14:30

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_editor', '0007_auto_20191218_1033'),
    ]

    operations = [
        migrations.AddField(
            model_name='codefragment',
            name='allow_create_backlink',
            field=models.BooleanField(default=True, help_text='set to False to disable backlink creation after Model save'),
        ),
        migrations.AddField(
            model_name='codefragment',
            name='is_backlink',
            field=models.BooleanField(default=False, help_text='set automatically to indicate the Model is a backlink'),
        ),
        migrations.AddField(
            model_name='helloworld',
            name='allow_create_backlink',
            field=models.BooleanField(default=True, help_text='set to False to disable backlink creation after Model save'),
        ),
        migrations.AddField(
            model_name='helloworld',
            name='is_backlink',
            field=models.BooleanField(default=False, help_text='set automatically to indicate the Model is a backlink'),
        ),
        migrations.AddField(
            model_name='user',
            name='allow_create_backlink',
            field=models.BooleanField(default=True, help_text='set to False to disable backlink creation after Model save'),
        ),
        migrations.AddField(
            model_name='user',
            name='is_backlink',
            field=models.BooleanField(default=False, help_text='set automatically to indicate the Model is a backlink'),
        ),
    ]
