# Generated by Django 2.2.24 on 2021-11-15 14:02

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_editor', '0009_auto_20211115_1449'),
    ]

    operations = [
        migrations.AlterField(
            model_name='codefragment',
            name='description',
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='codefragment',
            name='title',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='codefragment',
            name='title_en',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='codefragment',
            name='title_fr',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
    ]
